// Library for LCD functionality
#include <LiquidCrystal_I2C.h>

// Initialize LCD
LiquidCrystal_I2C lcd(0x27, 16, 2);

// Define pin numbers for the components
int riderCircuit = 8; // Pin connected to the riderCircuit
int slideSwitch = 11; // Pin connected to the slide switch
int buzzer = 7; // Pin connected to buzzer

void setup()
{
  // Start serial monitor
  Serial.begin(9600);

  // Initialize LCD
  lcd.init();
  lcd.backlight();

  // Set pin modes
  pinMode(slideSwitch, INPUT);
  pinMode(riderCircuit, OUTPUT);
  pinMode(buzzer, OUTPUT);
}

//Function for buzzer tone to be set
void buzzerTone(){ 
  tone(buzzer, 1000);
}

// Function to update the LCD depending on soil moisture sensor value
void setLCD()
{
  // Reads the value from soil moisture sensor
  int sensorVal = analogRead(A0);

  // Checks if the system is turned ON
  if (digitalRead(slideSwitch) == HIGH)
  {
    // Prints soil moisture sensor value 
    Serial.println(sensorVal);

    // Displays a certain message on the LCD depending on the soil moisture sensor value
    if (sensorVal <=250)
    {
      lcd.clear();
      lcd.print("Plant is");
      lcd.setCursor(0, 1);
      lcd.print("over watered!");
      delay(2000);
      lcd.clear();
      delay(2000);
    }          
    else if (sensorVal >= 425)
    {
      lcd.clear();
      lcd.print("Plant needs to");
      lcd.setCursor(0, 1);
      lcd.print("be watered!");
      delay(2000);
      lcd.clear();
      delay(2000);
    } 
    else
    {
      lcd.clear();
      lcd.print("Plant is watered!");
      delay(2000);
      lcd.clear();
      delay(2000);
    }
  }
  else
  {
    // Displays a message when the system is switched OFF
    Serial.println("Circuit is OFF");
    lcd.clear();
    delay(2000);
  }
}

// Function to control the rider circuit
void setRiderCircuit()
{
  // Reads the value from soil moisture sensor
  int sensorVal = analogRead(A0);

  // Check if the system is switched ON
  if (digitalRead(slideSwitch) == HIGH)
  {
    // Control the rider circuit based on soil moisture level
    if (sensorVal <= 300)
    {
      // If soil is overwatered, turn off the riderCircuit
      digitalWrite(riderCircuit, LOW);
      noTone(buzzer);
    }          
    else if (sensorVal >= 425)
    {
      // If soil is under watered, turn on the riderCircuit
      digitalWrite(riderCircuit, HIGH);
      buzzerTone();
    } 
    else
    {
      // If soil moisture sensor is water, keep riderCircuit off
      digitalWrite(riderCircuit, LOW);
      noTone(buzzer);
    }
  }
  else
  {
    // If slide switch is set to be switched OFF, keep riderCircuit off
    digitalWrite(riderCircuit, LOW);
    noTone(buzzer);
  }
}

void loop()
{
  // Call functions to update LCD and the riderCircuit
  setLCD();
  setRiderCircuit();
}
